@@ -1,4 +1,8 @@
-#include "dhidpihelper.h"
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
+#include "dtkwidget/util/dhidpihelper.h"
 
 #include <QPixmap>
 #include <QImageReader>
@@ -8,14 +12,15 @@
 DWIDGET_BEGIN_NAMESPACE
 
 /*!
- * \class DHiDPIHelper
- * \brief The DHiDPIHelper class provides helper to help applications support hiDPI.
+  \class Dtk::Widget::DHiDPIHelper
+  \inmodule dtkwidget
+  \brief The DHiDPIHelper class provides helper to help applications support hiDPI.
  */
 
 /*!
- * \brief DHiDPIHelper::loadNxPixmap loads the suitable @Nx image.
- * \param fileName is the original resource file name.
- * \return the hiDPI ready QPixmap.
+  \brief DHiDPIHelper::loadNxPixmap loads the suitable @Nx image.
+  \a fileName is the original resource file name.
+  \return the hiDPI ready QPixmap.
  */
 QPixmap DHiDPIHelper::loadNxPixmap(const QString &fileName)
 {
