@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include <QMouseEvent>
 #include <QApplication>
@@ -48,6 +35,14 @@ DAbstractDialogPrivate::DAbstractDialogPrivate(DAbstractDialog *qq):
 void DAbstractDialogPrivate::init(bool blurIfPossible)
 {
     D_Q(DAbstractDialog);
+    // TODO: 这里对dialog特殊处理，dialog不需要设置固定的位置，否则里面的坐标会发生偏移导致点击偏移
+    // 但是这不是问题的根本原因，还需要进一步分析。该属性在插件中做了特殊处理
+    q->QDialog::setProperty("DAbstractDialog", true);
+    auto noTitlebarEnabled = []{
+        QFunctionPointer enableNoTitlebar = qApp->platformFunction("_d_isEnableNoTitlebar");
+        bool enabled = qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
+        return enabled && enableNoTitlebar != nullptr;
+    };
 
     if (qApp->isDXcbPlatform()) {
         handle = new DPlatformWindowHandle(q, q);
@@ -70,7 +65,7 @@ void DAbstractDialogPrivate::init(bool blurIfPossible)
 
         bgBlurWidget->setBlurEnabled(blurIfPossible);
         q->setAttribute(Qt::WA_TranslucentBackground, blurIfPossible);
-    } else if (qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool()) {
+    } else if (noTitlebarEnabled()) {
         handle = new DPlatformWindowHandle(q, q);
         // fix wayland no titlebar
         //q->setWindowFlags(q->windowFlags() | Qt::FramelessWindowHint);
