@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include <QtGlobal>
 #ifdef Q_OS_LINUX
@@ -60,17 +47,8 @@
 #include <DFontSizeManager>
 #include <DTitlebar>
 
-#ifdef Q_OS_UNIX
-#include <QDBusError>
-#include <QDBusReply>
-#include <QDBusInterface>
-#include <QDBusPendingCall>
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
-#endif
-
 #ifdef Q_OS_LINUX
-#include "startupnotificationmonitor.h"
+#include "private/startupnotifications/startupnotificationmonitor.h"
 
 #include <DDBusSender>
 
@@ -85,43 +63,6 @@ DCORE_USE_NAMESPACE
 
 DWIDGET_BEGIN_NAMESPACE
 
-class LoadManualServiceWorker : public QThread
-{
-public:
-    explicit LoadManualServiceWorker(QObject *parent = nullptr);
-    ~LoadManualServiceWorker() override;
-    void checkManualServiceWakeUp();
-
-protected:
-    void run() override;
-};
-
-LoadManualServiceWorker::LoadManualServiceWorker(QObject *parent)
-    : QThread(parent)
-{
-    if (!parent)
-        connect(qApp, &QApplication::aboutToQuit, this, std::bind(&LoadManualServiceWorker::exit, this, 0));
-}
-
-LoadManualServiceWorker::~LoadManualServiceWorker()
-{
-}
-
-void LoadManualServiceWorker::run()
-{
-    QDBusInterface("com.deepin.Manual.Search",
-                   "/com/deepin/Manual/Search",
-                   "com.deepin.Manual.Search");
-}
-
-void LoadManualServiceWorker::checkManualServiceWakeUp()
-{
-    if (this->isRunning())
-        return;
-
-    start();
-}
-
 DApplicationPrivate::DApplicationPrivate(DApplication *q) :
     DObjectPrivate(q)
 {
@@ -293,7 +234,7 @@ bool DApplicationPrivate::loadDtkTranslator(QList<QLocale> localeFallback)
     qtTranslator->load("qtbase_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     q->installTranslator(qtbaseTranslator);
 
-    QList<DPathBuf> translateDirs;
+    QList<QString> translateDirs;
     auto dtkwidgetDir = DWIDGET_TRANSLATIONS_DIR;
     auto dtkwidgetName = "dtkwidget";
 
@@ -301,71 +242,14 @@ bool DApplicationPrivate::loadDtkTranslator(QList<QLocale> localeFallback)
     auto dataDirs = DStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
     for (const auto &path : dataDirs) {
         DPathBuf DPathBuf(path);
-        translateDirs << DPathBuf / dtkwidgetDir;
+        translateDirs << (DPathBuf / dtkwidgetDir).toString();
     }
 
-    DPathBuf runDir(q->applicationDirPath());
-    translateDirs << runDir.join("translations");
-
-    DPathBuf currentDir(QDir::currentPath());
-    translateDirs << currentDir.join("translations");
-
 #ifdef DTK_STATIC_TRANSLATION
-    translateDirs << DPathBuf(":/dtk/translations");
+    translateDirs << QString(":/dtk/translations");
 #endif
 
-    return loadTranslator(translateDirs, dtkwidgetName, localeFallback);
-}
-
-bool DApplicationPrivate::loadTranslator(QList<DPathBuf> translateDirs, const QString &name, QList<QLocale> localeFallback)
-{
-    D_Q(DApplication);
-
-    QStringList missingQmfiles;
-    for (auto &locale : localeFallback) {
-        QString translateFilename = QString("%1_%2").arg(name).arg(locale.name());
-        for (auto &path : translateDirs) {
-            QString translatePath = (path / translateFilename).toString();
-            if (QFile::exists(translatePath + ".qm")) {
-                qDebug() << "load translate" << translatePath;
-                auto translator = new QTranslator(q);
-                translator->load(translatePath);
-                q->installTranslator(translator);
-                return true;
-            }
-        }
-
-        // fix english does not need to translation..
-        if (locale.language() != QLocale::English) {
-            missingQmfiles << translateFilename + ".qm";
-        }
-
-        QStringList parseLocalNameList = locale.name().split("_", QString::SkipEmptyParts);
-        if (parseLocalNameList.length() > 0) {
-            translateFilename = QString("%1_%2").arg(name)
-                                .arg(parseLocalNameList.at(0));
-            for (auto &path : translateDirs) {
-                QString translatePath = (path / translateFilename).toString();
-                if (QFile::exists(translatePath + ".qm")) {
-                    qDebug() << "translatePath after feedback:" << translatePath;
-                    auto translator = new QTranslator(q);
-                    translator->load(translatePath);
-                    q->installTranslator(translator);
-                    return true;
-                }
-            }
-        }
-
-        // fix english does not need to translation..
-        if (locale.language() != QLocale::English) {
-            missingQmfiles << translateFilename + ".qm";
-        }
-    }
-
-    if (missingQmfiles.size() > 0) {
-        qWarning() << name << "can not find qm files" << missingQmfiles;
-    }
-    return false;
+    return DGuiApplicationHelper::loadTranslator(dtkwidgetName, translateDirs, localeFallback);
 }
 
 // 自动激活DMainWindow类型的窗口
@@ -505,47 +389,7 @@ void DApplicationPrivate::_q_resizeWindowContentsForVirtualKeyboard()
 
 bool DApplicationPrivate::isUserManualExists()
 {
-#ifdef Q_OS_LINUX
-    auto loadManualFromLocalFile = [=]() -> bool {
-        const QString appName = qApp->applicationName();
-        bool dmanAppExists = QFile::exists("/usr/bin/dman");
-        bool dmanDataExists = false;
-        // search all subdirectories
-        QString strManualPath = "/usr/share/deepin-manual";
-        QDirIterator it(strManualPath, QDirIterator::Subdirectories);
-        while (it.hasNext()) {
-            QFileInfo file(it.next());
-            if (file.isDir() && file.fileName().contains(appName, Qt::CaseInsensitive)) {
-                dmanDataExists = true;
-                break;
-            }
-
-            if (file.isDir())
-                continue;
-        }
-        return  dmanAppExists && dmanDataExists;
-    };
-
-    QDBusConnection conn = QDBusConnection::sessionBus();
-    if (conn.interface()->isServiceRegistered("com.deepin.Manual.Search")) {
-        QDBusInterface manualSearch("com.deepin.Manual.Search",
-                                    "/com/deepin/Manual/Search",
-                                    "com.deepin.Manual.Search");
-        if (manualSearch.isValid()) {
-            QDBusReply<bool> reply = manualSearch.call("ManualExists", qApp->applicationName());
-            return reply.value();
-        } else {
-            return loadManualFromLocalFile();
-        }
-    } else {
-        static LoadManualServiceWorker *manualWorker = new LoadManualServiceWorker;
-        manualWorker->checkManualServiceWakeUp();
-
-        return loadManualFromLocalFile();
-    }
-#else
-    return false;
-#endif
+    return DGuiApplicationHelper::instance()->hasUserManual();
 }
 
 /*!
@@ -876,24 +720,20 @@ bool DApplication::loadTranslator(QList<QLocale> localeFallback)
 
     d->loadDtkTranslator(localeFallback);
 
-    QList<DPathBuf> translateDirs;
+    QList<QString> translateDirs;
     auto appName = applicationName();
     //("/home/user/.local/share", "/usr/local/share", "/usr/share")
     auto dataDirs = DStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
     for (const auto &path : dataDirs) {
         DPathBuf DPathBuf(path);
-        translateDirs << DPathBuf / appName / "translations";
+        translateDirs << (DPathBuf / appName / "translations").toString();
     }
-    DPathBuf runDir(this->applicationDirPath());
-    translateDirs << runDir.join("translations");
-    DPathBuf currentDir(QDir::currentPath());
-    translateDirs << currentDir.join("translations");
 
 #ifdef DTK_STATIC_TRANSLATION
-    translateDirs << DPathBuf(":/dtk/translations");
+    translateDirs << QString(":/dtk/translations");
 #endif
 
-    return d->loadTranslator(translateDirs, appName, localeFallback);
+    return DGuiApplicationHelper::loadTranslator(appName, translateDirs, localeFallback);
 }
 
 /*!
@@ -1470,27 +1310,7 @@ void DApplication::handleHelpAction()
         d->appHandler->handleHelpAction();
         return;
     }
-    if (!DApplicationPrivate::isUserManualExists()) {
-        return;
-    }
-#ifdef Q_OS_LINUX
-    QString appid = applicationName();
-
-    // new interface use applicationName as id
-    QDBusInterface manual("com.deepin.Manual.Open",
-                          "/com/deepin/Manual/Open",
-                          "com.deepin.Manual.Open");
-    QDBusReply<void> reply = manual.call("ShowManual", appid);
-    if (reply.isValid())  {
-        qDebug() << "call com.deepin.Manual.Open success";
-        return;
-    }
-    qDebug() << "call com.deepin.Manual.Open failed" << reply.error();
-    // fallback to old interface
-    QProcess::startDetached("dman", QStringList() << appid);
-#else
-    qWarning() << "not support dman now";
-#endif
+    DGuiApplicationHelper::instance()->handleHelpAction();
 }
 
 /*!
