@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dfloatingbutton.h"
 #include "dstyleoption.h"
 #include "dobject_p.h"
@@ -65,6 +49,12 @@ DFloatingButton::DFloatingButton(const QIcon &icon, const QString &text, QWidget
     setText(text);
 }
 
+DFloatingButton::DFloatingButton(const DDciIcon &icon, const QString &text, QWidget *parent)
+    : DFloatingButton(text, parent)
+{
+    setIcon(icon);
+}
+
 DStyleOptionButton DFloatingButton::baseStyleOption() const
 {
     DStyleOptionButton opt;
@@ -77,6 +67,9 @@ void DFloatingButton::initStyleOption(DStyleOptionButton *option) const
 {
     DIconButton::initStyleOption(option);
     option->features = QStyleOptionButton::ButtonFeature(DStyleOptionButton::FloatingButton);
+
+    if (!option->dciIcon.isNull())
+        option->features |= QStyleOptionButton::ButtonFeature(DStyleOptionButton::HasDciIcon);
 }
 
 DWIDGET_END_NAMESPACE
