@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dsettingsdialog.h"
 
@@ -31,6 +18,7 @@
 #include "private/settings/content.h"
 #include "private/settings/navigation.h"
 
+#include "dapplication.h"
 #include "dspinbox.h"
 #include "dwindowclosebutton.h"
 
@@ -40,18 +28,15 @@ DWIDGET_BEGIN_NAMESPACE
 const int DefaultTitlebarHeight = 40;
 
 /*!
- * \~english \class DSettingsDialog
- * \brief DSettingsDialog provide an common setting ui for deepin style application.
- * It's depend Dtk::Widget::DSettingsWidgetFactory to auot build ui compent from json file.
- * \sa Dtk::Widget::DSettingsWidgetFactory
- * \sa Dtk::Core::DSettings
- */
+  \class Dtk::Widget::DSettingsDialog
+  \inmodule dtkwidget
 
-/*!
- * \~chinese \class DSettingsDialog
- * \brief 为使用DSettings的Dtk程序提供一个通用的设置对话框，这个对话框可以通过json配置文件来自动生成。
- * \sa Dtk::Widget::DSettingsWidgetFactory
- * \sa Dtk::Core::DSettings
+  \brief 为使用DSettings的Dtk程序提供一个通用的设置对话框，这个对话框可以通过json配置文件来自动生成.
+  \brief DSettingsDialog provide an common setting ui for deepin style application.
+  It's depend Dtk::Widget::DSettingsWidgetFactory to auot build ui compent from json file.
+
+  \sa Dtk::Widget::DSettingsWidgetFactory
+  \sa Dtk::Core::DSettings
  */
 
 class DSettingsDialogPrivate
@@ -118,8 +103,18 @@ DSettingsDialog::DSettingsDialog(QWidget *parent) :
         d->leftFrame->blockSignals(false);
     });
 
-    connect(this, &DSettingsDialog::windowIconChanged, d->frameBar, &DTitlebar::setIcon);
-    connect(this, &DSettingsDialog::windowTitleChanged, d->frameBar, &DTitlebar::setTitle);
+    DApplication *dapp = qobject_cast<DApplication*>(qApp);
+
+    if (dapp) {
+        d->content->setAttribute(Qt::WA_ContentsMarginsRespectsSafeArea, false);
+        d->content->setProperty("_dtk_NoTopLevelEnabled", true);
+        qApp->acclimatizeVirtualKeyboard(d->content);
+    }
+    // 修复 wayland 下使用 setwindowicon 程序出现死循环
+    if (DApplication::isDXcbPlatform()) {
+        connect(this, &DSettingsDialog::windowIconChanged, d->frameBar, &DTitlebar::setIcon);
+        connect(this, &DSettingsDialog::windowTitleChanged, d->frameBar, &DTitlebar::setTitle);
+    }
 }
 
 DSettingsDialog::~DSettingsDialog()
@@ -128,14 +123,13 @@ DSettingsDialog::~DSettingsDialog()
 }
 
 /*!
- * \~english \brief Return the widget build factory of this dialog.
- * Every instance of DSettingDialog has it own widgetfactory.
- * \return
- */
-/*!
- * \~chinese \brief 获取当前对话框使用的控件构造工厂。
- * 每一个设置对话框都有自己的构造工厂实例，这些实例并不会共享数据。
- * \return
+  \brief 获取当前对话框使用的控件构造工厂。
+  \brief Return the widget build factory of this dialog.
+
+  每一个设置对话框都有自己的构造工厂实例，这些实例并不会共享数据。
+  Every instance of DSettingDialog has it own widgetfactory.
+
+  \return
  */
 DSettingsWidgetFactory *DSettingsDialog::widgetFactory() const
 {
@@ -150,9 +144,9 @@ bool DSettingsDialog::groupIsVisible(const QString &groupKey) const
 }
 
 /*!
- * /~chinese \brief DSettingsDialog::setResetVisible 设置恢复默认设置按钮是否显示
- * /~chinese \param visible true显示 false隐藏
- * /~chinese \note 请在 updateSettings() 后调用
+  \brief DSettingsDialog::setResetVisible 设置恢复默认设置按钮是否显示
+  \a visible true显示 false隐藏
+  \note 请在 updateSettings() 后调用
  */
 void DSettingsDialog::setResetVisible(bool visible)
 {
@@ -165,9 +159,9 @@ void DSettingsDialog::setResetVisible(bool visible)
 }
 
 /*!
- * /~chinese \brief DSettingsDialog::scrollToGroup 使对话框跳转到指定的 group 项目
- * /~chinese \param groupKey DSettings中 groupKeys 以及其子项 childGroups
- * /~chinese \note 请在对话框 show 以后调用
+  \brief DSettingsDialog::scrollToGroup 使对话框跳转到指定的 group 项目
+  \a groupKey DSettings中 groupKeys 以及其子项 childGroups
+  \note 请在对话框 show 以后调用
  */
 void DSettingsDialog::scrollToGroup(const QString &groupKey)
 {
@@ -178,8 +172,8 @@ void DSettingsDialog::scrollToGroup(const QString &groupKey)
 }
 
 /*!
- * \brief DSettingsDialog::setIcon 设置标题栏的图标 QIcon
- * \param icon 设置的 Icon
+  \brief DSettingsDialog::setIcon 设置标题栏的图标 QIcon
+  \a icon 设置的 Icon
  */
 void DSettingsDialog::setIcon(const QIcon &icon)
 {
@@ -189,13 +183,12 @@ void DSettingsDialog::setIcon(const QIcon &icon)
 }
 
 /*!
- * \~english \brief Create all widget for settings options.
- * Warnning that you can only call the once.
- * \param settings Dtk::Core::DSettings object from json
- */
-/*!
- * \~chinese \brief 根据settings数据来创建控件，该方法只能调用一次。
- * \param settings 配置文件实例。
+  \brief Create all widget for settings options.
+  \brief 根据settings数据来创建控件，该方法只能调用一次。
+  Warnning that you can only call the once.
+
+  \a settings 配置文件实例。
+  \a settings Dtk::Core::DSettings object from json
  */
 void DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
 {
@@ -204,16 +197,15 @@ void DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
 }
 
 /*!
- * \~english \brief Create all widget for settings options with translate context
- * \param translateContext custom translate data for i18n.
- * \param settings Dtk::Core::DSettings object from json
- * \sa void DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
- */
-/*!
- * \~chinese \brief 根据settings数据来创建控件，并使用translateContext来进行国际化，该方法只能调用一次。
- * \param translateContext 国际化使用的上下文。
- * \param settings 配置文件实例。
- * \sa void DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
+  \brief 根据settings数据来创建控件，并使用translateContext来进行国际化，该方法只能调用一次.
+  \brief Create all widget for settings options with translate context.
+
+  \a translateContext 国际化使用的上下文。
+  \a translateContext custom translate data for i18n.
+  \a settings 配置文件实例。
+  \a settings Dtk::Core::DSettings object from json
+
+  \sa DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
  */
 void DSettingsDialog::updateSettings(const QByteArray &translateContext, Core::DSettings *settings)
 {
