@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2017 ~ 2019 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dstyleditemdelegate.h"
 #include "dobject_p.h"
 #include "dstyleoption.h"
@@ -35,12 +19,105 @@
 #include <QLineEdit>
 #include <QTableView>
 #include <QListWidget>
+#include <QPointer>
 #include <private/qlayoutengine_p.h>
+#include <DGuiApplicationHelper>
+#include <DDciIcon>
 
 Q_DECLARE_METATYPE(QMargins)
 
 DWIDGET_BEGIN_NAMESPACE
 
+struct ActionListData : public QSharedData {
+    explicit ActionListData() { }
+    explicit ActionListData(const DViewItemActionList& v)
+        : list(v)
+    {
+    }
+    ~ActionListData ()
+    {
+        qDeleteAll(list);
+    }
+    DViewItemActionList list;
+};
+
+class ActionList
+{
+public:
+    explicit ActionList() { }
+    explicit ActionList(ActionListData *data)
+        : m_data(data)
+    {
+    }
+    inline bool isValid() const
+    {
+        return m_data;
+    }
+    inline const ActionListData* constData() const
+    {
+        return m_data.constData();
+    }
+private:
+    friend QDataStream &operator<<(QDataStream &s, const ActionList &v);
+    friend QDataStream &operator>>(QDataStream &s, ActionList &v);
+    QSharedDataPointer<ActionListData> m_data;
+};
+
+QDataStream &operator<<(QDataStream &ds, const ActionList &v)
+{
+    quintptr data = reinterpret_cast<quintptr>(v.m_data.data());
+    ds << data;
+    return ds;
+}
+
+QDataStream &operator>>(QDataStream &ds, ActionList &v)
+{
+    quintptr data;
+    ds >> data;
+    v.m_data = reinterpret_cast<ActionListData *>(data);
+    return ds;
+}
+DWIDGET_END_NAMESPACE
+
+Q_DECLARE_METATYPE(DTK_WIDGET_NAMESPACE::ActionList)
+
+DWIDGET_BEGIN_NAMESPACE
+static void saveDViewItemActionList(QDataStream &s, const void *d)
+{
+    const ActionList &data = *static_cast<const ActionList*>(d);
+    s << data;
+}
+
+static void loadDViewItemActionList(QDataStream &s, void *d)
+{
+    ActionList &data = *static_cast<ActionList*>(d);
+    s >> data;
+}
+
+__attribute__((constructor))
+static void registerMetaType ()
+{
+    // register DViewItemActionList's stream operator to support that QMetaType can using save and load function.
+    QMetaType::registerStreamOperators(QMetaTypeId<DTK_WIDGET_NAMESPACE::ActionList>::qt_metatype_id(),
+                                       saveDViewItemActionList,
+                                       loadDViewItemActionList);
+}
+
+static DViewItemActionList qvariantToActionList(const QVariant &v)
+{
+    const ActionList &wrapper = v.value<ActionList>();
+    if (wrapper.isValid())
+        return wrapper.constData()->list;
+
+    return DViewItemActionList();
+}
+
+static QVariant actionListToQVariant(const DViewItemActionList &v)
+{
+    ActionList wrapper(new ActionListData(v));
+    return QVariant::fromValue(wrapper);
+}
+
 class DViewItemActionPrivate : public DCORE_NAMESPACE::DObjectPrivate
 {
 public:
@@ -55,7 +132,8 @@ public:
     QSize maxSize;
     QMargins clickMargins;
     bool clickable = false;
-    QWidget *widget = nullptr;
+    DDciIcon dciIcon;
+    QPointer<QWidget> widget = nullptr;
 
     qint8 colorType = -1;
     qint8 colorRole = -1;
@@ -116,7 +194,7 @@ public:
         return DStyle::viewItemSize(style, &item, Qt::DisplayRole);
     }
 
-    static QList<QRect> doActionsLayout(QRect base, const QList<DViewItemAction*> &list, Qt::Orientation orientation,
+    static QList<QRect> doActionsLayout(QRect base, const DViewItemActionList &list, Qt::Orientation orientation,
                                         Qt::LayoutDirection direction, const QSize &fallbackIconSize, QSize *bounding)
     {
         if (list.isEmpty()) {
@@ -272,14 +350,27 @@ public:
 
         // draw icon
         if (icon_size.isValid()) {
-            const QIcon &icon = action->icon();
             QRect icon_rect(QPoint(0, 0), icon_size);
 
             icon_rect.moveCenter(rect.center());
             icon_rect.moveLeft(rect.left());
 
-            auto modeStatePair = DStyle::toIconModeState(&option);
-            icon.paint(pa, icon_rect, Qt::AlignCenter, modeStatePair.first, modeStatePair.second);
+            if (action->dciIcon().isNull()) {
+                const QIcon &icon = action->icon();
+                auto modeStatePair = DStyle::toIconModeState(&option);
+                icon.paint(pa, icon_rect, Qt::AlignCenter, modeStatePair.first, modeStatePair.second);
+            } else {
+                DDciIcon dciicon = action->dciIcon();
+                DDciIcon::Mode mode = DStyle::toDciIconMode(&option);
+                auto appTheme = DGuiApplicationHelper::toColorType(option.palette);
+                DDciIcon::Theme theme = appTheme == DGuiApplicationHelper::LightType ? DDciIcon::Light : DDciIcon::Dark;
+                DDciIconPalette palette{option.palette.color(cg, QPalette::WindowText), option.palette.color(cg, QPalette::Window),
+                                        option.palette.color(cg, QPalette::Highlight), option.palette.color(cg, QPalette::HighlightedText)};
+                if (option.state & QStyle::State_Selected)
+                    palette.setForeground(option.palette.color(cg, QPalette::HighlightedText));
+                dciicon.paint(pa, icon_rect, pa->device() ? pa->device()->devicePixelRatio()
+                                                          : qApp->devicePixelRatio(), theme, mode, Qt::AlignCenter, palette);
+            }
         }
 
         // draw text
@@ -298,7 +389,7 @@ public:
 
     static QSize drawActions(QPainter *pa, const QStyleOptionViewItem &option, const QVariant &value, Qt::Edge edge, QList<QPair<QAction*, QRect>> *clickableActionRect)
     {
-        const DViewItemActionList &actionList = qvariant_cast<DViewItemActionList>(value);
+        const DViewItemActionList &actionList = qvariantToActionList(value);
         DViewItemActionList visiable_actionList;
         for (auto action : actionList) {
             if (action->isVisible())
@@ -341,12 +432,78 @@ public:
         return bounding;
     }
 
+    static DViewItemActionList allActions(const QModelIndex &index)
+    {
+        static const QVector<ItemDataRole> rules {
+            LeftActionListRole,
+                    TopActionListRole,
+                    RightActionListRole,
+                    BottomActionListRole,
+                    TextActionListRole
+        };
+        DViewItemActionList results;
+        for (const auto role: rules) {
+            const auto &list = qvariantToActionList(index.data(role));
+            if (list.isEmpty())
+                continue;
+            results << list;
+        }
+        return results;
+    }
+
+    bool readyRecordVisibleWidgetOfCurrentFrame()
+    {
+        // multi QEvent maybe be merged to one using postEvent
+        // so we can clear cache avoid to recording multi ItemWidget.
+        if (Q_UNLIKELY(hasStartRecord)) {
+            currentWidgets.clear();
+            return false;
+        }
+        hasStartRecord = true;
+        return true;
+    }
+
+    void updateWidgetVisibleInUnvisualArea()
+    {
+        hasStartRecord = false;
+        if (lastWidgets.isEmpty() && currentWidgets.isEmpty())
+            return;
+
+        for (const auto &widget : qAsConst(lastWidgets)) {
+            if (currentWidgets.contains(widget))
+                continue;
+            if (widget && widget->isVisible())
+                widget->setVisible(false);
+        }
+
+        lastWidgets.swap(currentWidgets);
+        currentWidgets.clear();
+    }
+
+    void recordVisibleWidgetOfCurrentFrame(const QModelIndex &index)
+    {
+        // only record virsual widget when starting record.
+        if (Q_UNLIKELY(!hasStartRecord))
+            return;
+
+        for (auto action : allActions(index)) {
+            if (!action->isVisible())
+                continue;
+
+            if (auto widget = action->widget())
+                currentWidgets.append(QPointer<QWidget>(widget));
+        }
+    }
+
     DStyledItemDelegate::BackgroundType backgroundType = DStyledItemDelegate::NoBackground;
     QMargins margins;
     QSize itemSize;
     int itemSpacing = 0;
     QMap<QModelIndex, QList<QPair<QAction*, QRect>>> clickableActionMap;
     QAction *pressedAction = nullptr;
+    QList<QPointer<QWidget>> lastWidgets;
+    QList<QPointer<QWidget>> currentWidgets;
+    bool hasStartRecord = false;
 };
 
 /*!
@@ -641,7 +798,7 @@ void DViewItemAction::setWidget(QWidget *widget)
 {
     D_D(DViewItemAction);
 
-    d->widget = widget;
+    d->widget = QPointer<QWidget>(widget);
     d->widget->setVisible(false);
 }
 
@@ -656,6 +813,20 @@ QWidget *DViewItemAction::widget() const
     return d->widget;
 }
 
+void DViewItemAction::setDciIcon(const DDciIcon &dciIcon)
+{
+    D_D(DViewItemAction);
+
+    d->dciIcon = dciIcon;
+}
+
+DDciIcon DViewItemAction::dciIcon() const
+{
+    D_DC(DViewItemAction);
+
+    return d->dciIcon;
+}
+
 static QPalette::ColorRole getViewItemColorRole(const QModelIndex &index, int role)
 {
     const QVariant &value = index.data(role);
@@ -776,7 +947,7 @@ void DStyledItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
         const_cast<DStyledItemDelegatePrivate*>(d)->clickableActionMap.remove(index);
     }
 
-    const DViewItemActionList &text_action_list = qvariant_cast<DViewItemActionList>(index.data(Dtk::TextActionListRole));
+    const DViewItemActionList &text_action_list = qvariantToActionList(index.data(Dtk::TextActionListRole));
 
     opt.rect = itemContentRect;
     QRect iconRect, textRect, checkRect;
@@ -797,13 +968,31 @@ void DStyledItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
 
     // draw icon
     if (opt.features & QStyleOptionViewItem::HasDecoration) {
-        QIcon::Mode mode = QIcon::Normal;
-        if (!(opt.state & QStyle::State_Enabled))
-            mode = QIcon::Disabled;
-        else if (opt.state & QStyle::State_Selected)
-            mode = QIcon::Selected;
-        QIcon::State state = opt.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
-        opt.icon.paint(painter, iconRect, opt.decorationAlignment, mode, state);
+        QVariant icon = index.data(Qt::DecorationRole);
+        DDciIcon dciIcon;
+        if (icon.canConvert<DTK_GUI_NAMESPACE::DDciIcon>())
+            dciIcon = qvariant_cast<DDciIcon>(icon);
+
+        if (dciIcon.isNull()) {
+            QIcon::Mode mode = QIcon::Normal;
+            if (!(opt.state & QStyle::State_Enabled))
+                mode = QIcon::Disabled;
+            else if (opt.state & QStyle::State_Selected)
+                mode = QIcon::Selected;
+            QIcon::State state = opt.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
+            opt.icon.paint(painter, iconRect, opt.decorationAlignment, mode, state);
+        } else {
+            DDciIcon::Mode mode = DStyle::toDciIconMode(&option);
+            auto appTheme = DGuiApplicationHelper::toColorType(option.palette);
+            DDciIcon::Theme theme = appTheme == DGuiApplicationHelper::LightType ? DDciIcon::Light : DDciIcon::Dark;
+            DDciIconPalette palette{option.palette.color(cg, QPalette::WindowText), option.palette.color(cg, QPalette::Window),
+                                    option.palette.color(cg, QPalette::Highlight), option.palette.color(cg, QPalette::HighlightedText)};
+            if (option.state & QStyle::State_Selected)
+                palette.setForeground(opt.palette.color(cg, QPalette::HighlightedText));
+            dciIcon.paint(painter, iconRect, painter->device() ? painter->device()->devicePixelRatioF()
+                                                               : qApp->devicePixelRatio(),
+                          theme, mode, Qt::AlignCenter, palette);
+        }
     }
 
     // draw the text
@@ -884,6 +1073,8 @@ void DStyledItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
                                               ? QPalette::Highlight : QPalette::Window);
         style->drawPrimitive(QStyle::PE_FrameFocusRect, &o, painter, widget);
     }
+
+    const_cast<DStyledItemDelegatePrivate*>(d)->recordVisibleWidgetOfCurrentFrame(index);
 }
 
 QSize DStyledItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -906,7 +1097,7 @@ QSize DStyledItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QM
     QRect pixmapRect, textRect, checkRect;
     DStyle::viewItemLayout(style, &opt, &pixmapRect, &textRect, &checkRect, true);
 
-    const DViewItemActionList &text_action_list = qvariant_cast<DViewItemActionList>(index.data(Dtk::TextActionListRole));
+    const DViewItemActionList &text_action_list = qvariantToActionList(index.data(Dtk::TextActionListRole));
 
     for (const DViewItemAction *action : text_action_list) {
         const QSize &action_size = d->displayActionSize(action, style, opt);
@@ -916,10 +1107,10 @@ QSize DStyledItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QM
 
     QSize size = (pixmapRect | textRect | checkRect).size();
 
-    const DViewItemActionList &left_actions = qvariant_cast<QList<DViewItemAction*>>(index.data(Dtk::LeftActionListRole));
-    const DViewItemActionList &right_actions = qvariant_cast<QList<DViewItemAction*>>(index.data(Dtk::RightActionListRole));
-    const DViewItemActionList &top_actions = qvariant_cast<QList<DViewItemAction*>>(index.data(Dtk::TopActionListRole));
-    const DViewItemActionList &bottom_actions = qvariant_cast<QList<DViewItemAction*>>(index.data(Dtk::BottomActionListRole));
+    const DViewItemActionList &left_actions = qvariantToActionList(index.data(Dtk::LeftActionListRole));
+    const DViewItemActionList &right_actions = qvariantToActionList(index.data(Dtk::RightActionListRole));
+    const DViewItemActionList &top_actions = qvariantToActionList(index.data(Dtk::TopActionListRole));
+    const DViewItemActionList &bottom_actions = qvariantToActionList(index.data(Dtk::BottomActionListRole));
 
     QSize action_area_size;
     // 获取左边区域大小
@@ -1084,6 +1275,25 @@ void DStyledItemDelegate::initStyleOption(QStyleOptionViewItem *option, const QM
 {
     QStyledItemDelegate::initStyleOption(option, index);
 
+    QVariant value = index.data(Qt::DecorationRole);
+    if (value.canConvert<DDciIcon>()) {
+        // The dciicon can not be set to opt.icon
+        auto dciIcon = qvariant_cast<DDciIcon>(value);
+        DDciIcon::Mode mode;
+        if (!(option->state & QStyle::State_Enabled))
+            mode = DDciIcon::Disabled;
+        else if (option->state & QStyle::State_Selected)
+            mode = DDciIcon::Pressed;
+        else
+            mode = DDciIcon::Normal;
+        auto appTheme = DGuiApplicationHelper::toColorType(option->palette);
+        DDciIcon::Theme theme = appTheme == DGuiApplicationHelper::LightType ? DDciIcon::Light : DDciIcon::Dark;
+        int actualSize = dciIcon.actualSize(option->decorationSize.width(), theme, mode);
+        // For highdpi icons actualSize might be larger than decorationSize, which we don't want. Clamp it to decorationSize.
+        option->decorationSize = QSize(qMin(option->decorationSize.width(), actualSize),
+                                       qMin(option->decorationSize.height(), actualSize));
+    }
+
     if (option->viewItemPosition == QStyleOptionViewItem::ViewItemPosition::Invalid) {
         const int rowCount =  index.model()->rowCount();
         if (rowCount == 1) {
@@ -1185,6 +1395,23 @@ bool DStyledItemDelegate::eventFilter(QObject *object, QEvent *event)
     default:
         break;
     }
+    const auto view = qobject_cast<QAbstractItemView*>(parent());
+    if (view && object == view->viewport()) {
+        static const QEvent::Type UpdateWidgetVisibleEvent(
+                    static_cast<QEvent::Type>(QEvent::registerEventType()));
+
+        if (event->type() == QEvent::Paint) {
+            D_D(DStyledItemDelegate);
+            if (d->readyRecordVisibleWidgetOfCurrentFrame()) {
+                auto updateEvent = new QEvent(UpdateWidgetVisibleEvent);
+                qApp->postEvent(view->viewport(), updateEvent);
+            }
+        } else if (event->type() == UpdateWidgetVisibleEvent) {
+            D_D(DStyledItemDelegate);
+            d->updateWidgetVisibleInUnvisualArea();
+            return true;
+        }
+    }
 
     return QStyledItemDelegate::eventFilter(object, event);
 }
@@ -1207,13 +1434,6 @@ static Dtk::ItemDataRole getActionPositionRole(Qt::Edge edge)
     return Dtk::LeftActionListRole;
 }
 
-static void clearActions(const DViewItemActionList &list)
-{
-    for (auto action : list) {
-        action->deleteLater();
-    }
-}
-
 /*!
   \class Dtk::Widget::DStandardItem
   \inmodule dtkwidget
@@ -1227,11 +1447,6 @@ static void clearActions(const DViewItemActionList &list)
  */
 DStandardItem::~DStandardItem()
 {
-    for (Qt::Edge e : {Qt::TopEdge, Qt::LeftEdge, Qt::RightEdge, Qt::BottomEdge}) {
-        clearActions(qvariant_cast<DViewItemActionList>(data(getActionPositionRole(e))));
-    }
-
-    clearActions(textActionList());
 }
 
 /*!
@@ -1245,11 +1460,10 @@ void DStandardItem::setActionList(Qt::Edge edge, const DViewItemActionList &list
     QVariant value;
 
     if (!list.isEmpty()) {
-        value = QVariant::fromValue(list);
+        value = actionListToQVariant(list);;
     }
 
     auto role = getActionPositionRole(edge);
-    clearActions(qvariant_cast<DViewItemActionList>(data(role)));
     setData(value, role);
 }
 
@@ -1260,7 +1474,7 @@ void DStandardItem::setActionList(Qt::Edge edge, const DViewItemActionList &list
  */
 DViewItemActionList DStandardItem::actionList(Qt::Edge edge) const
 {
-    return qvariant_cast<DViewItemActionList>(data(getActionPositionRole(edge)));
+    return qvariantToActionList(data(getActionPositionRole(edge)));
 }
 
 /*!
@@ -1313,10 +1527,9 @@ void DStandardItem::setTextActionList(const DViewItemActionList &list)
     QVariant value;
 
     if (!list.isEmpty()) {
-        value = QVariant::fromValue(list);
+        value = actionListToQVariant(list);;
     }
 
-    clearActions(textActionList());
     setData(value, Dtk::TextActionListRole);
 }
 
@@ -1325,7 +1538,7 @@ void DStandardItem::setTextActionList(const DViewItemActionList &list)
  */
 DViewItemActionList DStandardItem::textActionList() const
 {
-    return qvariant_cast<DViewItemActionList>(data(Dtk::TextActionListRole));
+    return qvariantToActionList(data(Dtk::TextActionListRole));
 }
 
 void DStandardItem::setTextColorRole(DPalette::ColorType role)
@@ -1378,4 +1591,19 @@ QFont DStandardItem::font() const
     return getViewItemFont(index(), Dtk::ViewItemFontLevelRole);
 }
 
+void DStandardItem::setDciIcon(const DDciIcon &dciIcon)
+{
+    setData(QVariant::fromValue<DDciIcon>(dciIcon), Qt::DecorationRole);
+}
+
+DDciIcon DStandardItem::dciIcon() const
+{
+    return qvariant_cast<DDciIcon>(data(Qt::DecorationRole));
+}
+
+QStandardItem *DStandardItem::clone() const
+{
+    return new DStandardItem(*this);
+}
+
 DWIDGET_END_NAMESPACE
