@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dtitlebar.h"
 
@@ -148,7 +135,7 @@ private:
     bool                autoHideOnFullscreen = false;
     bool                fullScreenButtonVisible = true;
     bool                splitScreenWidgetEnable = true;
-
+    QTimer              *maxButtonPressAndHoldTimer = nullptr;
     Q_DECLARE_PUBLIC(DTitlebar)
 };
 
@@ -177,7 +164,8 @@ void DSplitScreenButton::initStyleOption(DStyleOptionButton *option) const
         QColor iconForeColor = Qt::white;
         if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
             backgroundBrush = DStyle::adjustColor(backgroundBrush, 0, 0, 0, 0, 0, 0, 3);
-            iconForeColor = dpal.textTiele().color();
+            iconForeColor = dpal.brush(DPalette::TextTitle).color();
+
         }
 
         pal.setBrush(QPalette::Light, backgroundBrush);
@@ -211,10 +199,10 @@ void DSplitScreenWidget::hideImmediately()
 void DSplitScreenWidget::updateMaximizeButtonIcon(bool isMaximized)
 {
     if (isMaximized) {
-        this->maximizeButton->setIcon(DStyle::SP_Title_SS_ShowMaximizeButton);
+        this->maximizeButton->setIcon(DStyle::SP_Title_SS_ShowNormalButton);
         this->maximizeButton->setToolTip(qApp->translate("DSplitScreenWidget", "Unmaximize"));
     } else {
-        this->maximizeButton->setIcon(DStyle::SP_Title_SS_ShowNormalButton);
+        this->maximizeButton->setIcon(DStyle::SP_Title_SS_ShowMaximizeButton);
         this->maximizeButton->setToolTip(qApp->translate("DSplitScreenWidget", "Maximize"));
     }
 }
@@ -313,11 +301,15 @@ bool DSplitScreenWidget::eventFilter(QObject *o, QEvent *e)
     case QEvent::WindowDeactivate:
     case QEvent::FocusIn:
     case QEvent::FocusOut:
-    case QEvent::MouseButtonRelease:
     case QEvent::MouseButtonDblClick:
     case QEvent::Wheel:
         hideImmediately();
         break;
+    case QEvent::MouseButtonRelease:
+        if (!isMaxButtonPressAndHold) {
+            hideImmediately();
+        }
+        break;
     default:
         break;
     }
@@ -375,6 +367,8 @@ void DTitlebarPrivate::init()
     minButton       = new DWindowMinButton;
     maxButton       = new DWindowMaxButton;
     closeButton     = new DWindowCloseButton;
+    maxButtonPressAndHoldTimer = new QTimer(q);
+    maxButtonPressAndHoldTimer->setSingleShot(true);
 
     if (DGuiApplicationHelper::isTabletEnvironment()) {
         optionButton = new DTabletWindowOptionButton;
@@ -409,6 +403,7 @@ void DTitlebarPrivate::init()
 
     iconLabel->setIconSize(QSize(DefaultIconWidth, DefaultIconHeight));
     iconLabel->setWindowFlags(Qt::WindowTransparentForInput);
+    iconLabel->setAttribute( Qt::WA_TransparentForMouseEvents, true);
     iconLabel->setFocusPolicy(Qt::NoFocus);
     iconLabel->setAccessibleName("DTitlebarIconLabel");
     iconLabel->setFlat(true);
@@ -494,6 +489,11 @@ void DTitlebarPrivate::init()
     q->connect(DGuiApplicationHelper::instance()->systemTheme(), &DPlatformTheme::iconThemeNameChanged, q, [ = ]() {
         iconLabel->update();
     });
+    q->connect(maxButtonPressAndHoldTimer, &QTimer::timeout, q, [this]() {
+        showSplitScreenWidget();
+        if (splitWidget && splitWidget->isVisible())
+            splitWidget->isMaxButtonPressAndHold = true;
+    });
 
     // 默认需要构造一个空的选项菜单
     q->setMenu(new QMenu(q));
@@ -505,8 +505,13 @@ void DTitlebarPrivate::init()
     // 另外，让标题栏接收焦点，还是为了避免一个focus控件隐藏时，会把焦点转移给标题栏上的按钮控件
     q->setFocusPolicy(Qt::StrongFocus);
 
+    auto noTitlebarEnabled = []{
+        QFunctionPointer enableNoTitlebar = qApp->platformFunction("_d_isEnableNoTitlebar");
+        bool enabled = qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
+        return enabled && enableNoTitlebar != nullptr;
+    };
     // fix wayland 下显示了两个应用图标，系统标题栏 和 dtk标题栏 均显示应用图标
-    q->setEmbedMode(!(DApplication::isDXcbPlatform()|| (qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool())));
+    q->setEmbedMode(!(DApplication::isDXcbPlatform()|| noTitlebarEnabled()));
 }
 
 QWidget *DTitlebarPrivate::targetWindow()
@@ -627,7 +632,11 @@ void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
 void DTitlebarPrivate::updateButtonsFunc()
 {
     // TASK-18145 (bug-17474) do not setMotifFunctions on wayland
-    if (!targetWindowHandle || !qgetenv("WAYLAND_DISPLAY").isEmpty()) {
+    if (!targetWindowHandle) {
+        return;
+    }
+    if (!qgetenv("WAYLAND_DISPLAY").isEmpty()) {
+        closeButton->setEnabled(!disableFlags.testFlag(Qt::WindowCloseButtonHint));
         return;
     }
 
@@ -666,7 +675,7 @@ void DTitlebarPrivate::updateCenterArea()
 
 void DTitlebarPrivate::handleParentWindowStateChange()
 {
-    maxButton->setMaximized(targetWindow()->windowState() == Qt::WindowMaximized);
+    maxButton->setMaximized(targetWindow()->windowState().testFlag(Qt::WindowMaximized));
     updateFullscreen();
     updateButtonsState(targetWindow()->windowFlags());
 }
@@ -689,6 +698,11 @@ void DTitlebarPrivate::handleParentWindowIdChange()
 
 void DTitlebarPrivate::_q_toggleWindowState()
 {
+    if (splitWidget && splitWidget->isMaxButtonPressAndHold) {
+        splitWidget->isMaxButtonPressAndHold = false;
+        return;
+    }
+
     QWidget *parentWindow = targetWindow();
 
     if (!parentWindow || disableFlags.testFlag(Qt::WindowMaximizeButtonHint)) {
@@ -744,7 +758,11 @@ void DTitlebarPrivate::_q_onTopWindowMotifHintsChanged(quint32 winId)
     minButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_MINIMIZE));
     maxButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_MAXIMIZE)
                           && functions_hints.testFlag(DWindowManagerHelper::FUNC_RESIZE));
-    closeButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_CLOSE));
+    if (!qgetenv("WAYLAND_DISPLAY").isEmpty()) {
+        closeButton->setEnabled(!disableFlags.testFlag(Qt::WindowCloseButtonHint));
+    } else {
+        closeButton->setEnabled(functions_hints.testFlag(DWindowManagerHelper::FUNC_CLOSE));
+    }
     // sync button state
 #if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     disableFlags.setFlag(Qt::WindowMinimizeButtonHint, !minButton->isEnabled());
@@ -986,10 +1004,14 @@ void DTitlebarPrivate::hideSplitScreenWidget()
 
 void DTitlebarPrivate::changeWindowSplitedState(quint32 type)
 {
-    //### 目前接口尚不公开在 dtkgui 中，等待获取后续接口稳定再做移植
+    if (splitWidget && splitWidget->isVisible()) {
+        splitWidget->isMaxButtonPressAndHold = false;
+        splitWidget->hideImmediately();
+    }
     D_Q(DTitlebar);
     QFunctionPointer splitWindowOnScreen = Q_NULLPTR;
 
+    //### 目前接口尚不公开在 dtkgui 中，等待获取后续接口稳定再做移植
     splitWindowOnScreen = qApp->platformFunction(CHANGESPLITWINDOW_VAR);
 
     const QWindow *windowHandle = nullptr;
@@ -1138,12 +1160,8 @@ void DTitlebar::showMenu()
 {
     D_D(DTitlebar);
 
-#ifndef QT_NO_MENU
-    // 默认菜单应该是showmenu之前添加, 而非showevent
-    d->_q_addDefaultMenuItems();
-#endif
-     if (d->helpAction)
-         d->helpAction->setVisible(DApplicationPrivate::isUserManualExists());
+    if (d->helpAction)
+        d->helpAction->setVisible(DApplicationPrivate::isUserManualExists());
 
     if (d->menu) {
         // 更新主题选中的项
@@ -1187,6 +1205,11 @@ void DTitlebar::showEvent(QShowEvent *event)
     d->separator->setFixedWidth(width());
     d->separator->move(0, height() - d->separator->height());
 
+#ifndef QT_NO_MENU
+    // 默认菜单需要在showevent添加，否则`menu`接口返回空actions，导致接口逻辑不兼容
+    d->_q_addDefaultMenuItems();
+#endif
+
     QWidget::showEvent(event);
 
     if (DPlatformWindowHandle::isEnabledDXcb(window())) {
@@ -1276,6 +1299,14 @@ bool DTitlebar::eventFilter(QObject *obj, QEvent *event)
             d->hideSplitScreenWidget();
             break;
         }
+        case QEvent::MouseButtonPress: {
+            d->maxButtonPressAndHoldTimer->start(300);
+            break;
+        }
+        case QEvent::MouseButtonRelease: {
+            d->maxButtonPressAndHoldTimer->stop();
+            break;
+        }
         default:
             break;
 
